=== modified file 'README'
--- README	2010-11-16 12:46:25 +0000
+++ README	2011-06-23 11:23:24 +0000
@@ -13,4 +13,4 @@
 ==============
 
 All bugs should be reported to the launchpad project at
-https://bugs.launchpad.net/linaro-launch-control-tool/+filebug
+https://bugs.launchpad.net/lava-dashboard-tool/+filebug

=== renamed directory 'launch_control_tool' => 'lava_dashboard_tool'
=== modified file 'lava_dashboard_tool/__init__.py'
--- launch_control_tool/__init__.py	2011-06-23 11:13:22 +0000
+++ lava_dashboard_tool/__init__.py	2011-06-23 11:23:24 +0000
@@ -2,19 +2,19 @@
 #
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 #
-# This file is part of launch-control-tool.
+# This file is part of lava-dashboard-tool.
 #
-# launch-control-tool is free software: you can redistribute it and/or modify
+# lava-dashboard-tool is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License version 3
 # as published by the Free Software Foundation
 #
-# launch-control-tool is distributed in the hope that it will be useful,
+# lava-dashboard-tool is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with launch-control-tool.  If not, see <http://www.gnu.org/licenses/>.
+# along with lava-dashboard-tool.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 Launch Control Tool package

=== modified file 'lava_dashboard_tool/commands.py'
--- launch_control_tool/commands.py	2011-06-23 11:13:22 +0000
+++ lava_dashboard_tool/commands.py	2011-06-23 11:23:24 +0000
@@ -2,19 +2,19 @@
 #
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 #
 # This file is part of launch-control-tool.
 #
 # launch-control-tool is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License version 3
 # as published by the Free Software Foundation
 #
 # launch-control-tool is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with launch-control-tool.  If not, see <http://www.gnu.org/licenses/>.
+# along with lava-dashboard-tool.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 Module with command-line tool commands that interact with the dashboard
@@ -950,6 +950,6 @@
     """
     def invoke(self):
         import versiontools
-        from launch_control_tool import __version__
+        from lava_dashboard_tool import __version__
         print "Dashboard client version: {version}".format(
             version=versiontools.format_version(__version__))
@@ -2,19 +2,19 @@
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 #
-# This file is part of launch-control-tool.
+# This file is part of lava-dashboard-tool.
 #
@@ -2,19 +2,19 @@
 #
-# launch-control-tool is free software: you can redistribute it and/or modify
+# lava-dashboard-tool is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License version 3
 # as published by the Free Software Foundation
@@ -2,19 +2,19 @@
 # as published by the Free Software Foundation
 #
-# launch-control-tool is distributed in the hope that it will be useful,
+# lava-dashboard-tool is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the

=== modified file 'lava_dashboard_tool/main.py'
--- launch_control_tool/main.py	2011-05-04 12:39:22 +0000
+++ lava_dashboard_tool/main.py	2011-06-23 11:23:24 +0000
@@ -3,19 +3,19 @@
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 # Author: Michael Hudson-Doyle <michael.hudson@linaro.org>
 #
 # This file is part of launch-control-tool.
 #
 # launch-control-tool is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License version 3
 # as published by the Free Software Foundation
 #
 # launch-control-tool is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with launch-control-tool.  If not, see <http://www.gnu.org/licenses/>.
+# along with lava-dashboard-tool.  If not, see <http://www.gnu.org/licenses/>.
 
 
 from lava_tool.dispatcher import LavaDispatcher, run_with_dispatcher_class
@@ -23,13 +23,13 @@
 
 class LaunchControlDispatcher(LavaDispatcher):
 
-    toolname = 'launch_control_tool'
+    toolname = 'lava_dashboard_tool'
     description = """
     Command line tool for interacting with Launch Control
     """
     epilog = """
     Please report all bugs using the Launchpad bug tracker:
-    http://bugs.launchpad.net/launch-control-tool/+filebug
+    http://bugs.launchpad.net/lava-dashboard-tool/+filebug
     """
 
 
@@ -3,19 +3,19 @@
 # Author: Michael Hudson-Doyle <michael.hudson@linaro.org>
 #
-# This file is part of launch-control-tool.
+# This file is part of lava-dashboard-tool.
 #
@@ -3,19 +3,19 @@
 #
-# launch-control-tool is free software: you can redistribute it and/or modify
+# lava-dashboard-tool is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License version 3
 # as published by the Free Software Foundation
@@ -3,19 +3,19 @@
 # as published by the Free Software Foundation
 #
-# launch-control-tool is distributed in the hope that it will be useful,
+# lava-dashboard-tool is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the

=== modified file 'lava_dashboard_tool/tests/__init__.py'
--- launch_control_tool/tests/__init__.py	2011-05-04 12:39:22 +0000
+++ lava_dashboard_tool/tests/__init__.py	2011-06-23 11:23:24 +0000
@@ -2,22 +2,22 @@
 #
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 #
 # This file is part of launch-control-tool.
 #
 # launch-control-tool is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License version 3
 # as published by the Free Software Foundation
 #
 # launch-control-tool is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with launch-control-tool.  If not, see <http://www.gnu.org/licenses/>.
+# along with lava-dashboard-tool.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-Package with unit tests for launch_control_tool
+Package with unit tests for lava_dashboard_tool
 """
 
 import doctest
@@ -26,13 +26,13 @@
 
 def app_modules():
     return [
-            'launch_control_tool.commands',
+            'lava_dashboard_tool.commands',
             ]
 
 
 def test_modules():
     return [
-            'launch_control_tool.tests.test_commands',
+            'lava_dashboard_tool.tests.test_commands',
             ]
 
 
@@ -2,22 +2,22 @@
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 #
-# This file is part of launch-control-tool.
+# This file is part of lava-dashboard-tool.
 #
@@ -2,22 +2,22 @@
 #
-# launch-control-tool is free software: you can redistribute it and/or modify
+# lava-dashboard-tool is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License version 3
 # as published by the Free Software Foundation
@@ -2,22 +2,22 @@
 # as published by the Free Software Foundation
 #
-# launch-control-tool is distributed in the hope that it will be useful,
+# lava-dashboard-tool is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the

=== modified file 'lava_dashboard_tool/tests/test_commands.py'
--- launch_control_tool/tests/test_commands.py	2011-05-04 12:39:22 +0000
+++ lava_dashboard_tool/tests/test_commands.py	2011-06-23 11:23:24 +0000
@@ -2,19 +2,19 @@
 #
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 #
 # This file is part of launch-control-tool.
 #
 # launch-control-tool is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License version 3
 # as published by the Free Software Foundation
 #
 # launch-control-tool is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with launch-control-tool.  If not, see <http://www.gnu.org/licenses/>.
+# along with lava-dashboard-tool.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 Unit tests for the launch_control.commands package
@@ -22,7 +22,7 @@
 
 from unittest import TestCase
 
-from launch_control_tool.commands import XMLRPCCommand
+from lava_dashboard_tool.commands import XMLRPCCommand
 
 
 class XMLRPCCommandTestCase(TestCase):
@@ -2,19 +2,19 @@
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 #
-# This file is part of launch-control-tool.
+# This file is part of lava-dashboard-tool.
 #
@@ -2,19 +2,19 @@
 #
-# launch-control-tool is free software: you can redistribute it and/or modify
+# lava-dashboard-tool is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License version 3
 # as published by the Free Software Foundation
@@ -2,19 +2,19 @@
 # as published by the Free Software Foundation
 #
-# launch-control-tool is distributed in the hope that it will be useful,
+# lava-dashboard-tool is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the

=== modified file 'setup.py'
--- setup.py	2011-06-23 11:13:22 +0000
+++ setup.py	2011-06-23 11:23:24 +0000
@@ -4,50 +4,50 @@
 #
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 #
 # This file is part of launch-control-tool.
 #
 # launch-control-tool is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License version 3
 # as published by the Free Software Foundation
 #
 # launch-control-tool is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with launch-control-tool.  If not, see <http://www.gnu.org/licenses/>.
+# along with lava-dashboard-tool.  If not, see <http://www.gnu.org/licenses/>.
 
 from setuptools import setup, find_packages
 
 
 setup(
-    name='launch-control-tool',
-    version=":versiontools:launch_control_tool:__version__",
+    name='lava-dashboard-tool',
+    version=":versiontools:lava_dashboard_tool:__version__",
     author="Zygmunt Krynicki",
     author_email="zygmunt.krynicki@linaro.org",
     packages=find_packages(),
     description="Command line utility for Launch Control",
-    url='https://launchpad.net/launch-control-tool',
-    test_suite='launch_control_tool.tests.test_suite',
+    url='https://launchpad.net/lava-dashboard-tool',
+    test_suite='lava_dashboard_tool.tests.test_suite',
     license="LGPLv3",
     entry_points="""
     [console_scripts]
-    lc-tool=launch_control_tool.main:main
-    [launch_control_tool.commands]
-    backup=launch_control_tool.commands:backup
-    bundles=launch_control_tool.commands:bundles
-    data_views=launch_control_tool.commands:data_views
-    deserialize=launch_control_tool.commands:deserialize
-    get=launch_control_tool.commands:get
-    make_stream=launch_control_tool.commands:make_stream
-    pull=launch_control_tool.commands:pull
-    put=launch_control_tool.commands:put
-    query_data_view=launch_control_tool.commands:query_data_view
-    restore=launch_control_tool.commands:restore
-    server_version=launch_control_tool.commands:server_version
-    streams=launch_control_tool.commands:streams
-    version=launch_control_tool.commands:version
+    lava-dashboard-tool=lava_dashboard_tool.main:main
+    [lava_dashboard_tool.commands]
+    backup=lava_dashboard_tool.commands:backup
+    bundles=lava_dashboard_tool.commands:bundles
+    data_views=lava_dashboard_tool.commands:data_views
+    deserialize=lava_dashboard_tool.commands:deserialize
+    get=lava_dashboard_tool.commands:get
+    make_stream=lava_dashboard_tool.commands:make_stream
+    pull=lava_dashboard_tool.commands:pull
+    put=lava_dashboard_tool.commands:put
+    query_data_view=lava_dashboard_tool.commands:query_data_view
+    restore=lava_dashboard_tool.commands:restore
+    server_version=lava_dashboard_tool.commands:server_version
+    streams=lava_dashboard_tool.commands:streams
+    version=lava_dashboard_tool.commands:version
     """,
     classifiers=[
         "Development Status :: 4 - Beta",
@@ -4,50 +4,50 @@
 # Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
 #
-# This file is part of launch-control-tool.
+# This file is part of lava-dashboard-tool.
 #
@@ -4,50 +4,50 @@
 #
-# launch-control-tool is free software: you can redistribute it and/or modify
+# lava-dashboard-tool is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License version 3
 # as published by the Free Software Foundation
@@ -4,50 +4,50 @@
 # as published by the Free Software Foundation
 #
-# launch-control-tool is distributed in the hope that it will be useful,
+# lava-dashboard-tool is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the

